@@ -1,7 +1,7 @@
 // qxgeditOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -50,8 +50,12 @@ public:
 
 	// Command line arguments parser.
 	bool parse_args(const QStringList& args);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+	void show_error(const QString& msg);
+#else
 	// Command line usage helper.
 	void print_usage(const QString& arg0);
+#endif
 
 	// Startup supplied session file.
 	QString sSessionFile;
