@@ -1,7 +1,7 @@
 // qxgeditOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -48,7 +48,9 @@ qxgeditOptionsForm::qxgeditOptionsForm ( QWidget *pParent )
 {
 	// Setup UI struct...
 	m_ui.setupUi(this);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 1, 0)
+	QDialog::setWindowIcon(QIcon(":/images/qxgedit.png"));
+#endif
 	// No settings descriptor initially (the caller will set it).
 	m_pOptions = nullptr;
 
